#include <sfi/sfi.h>


/*-------- begin ../sfi/sfidl generated code --------*/



#define bse_int_seq_new foo_prefix_bse_int_seq_new
#define bse_int_seq_append foo_prefix_bse_int_seq_append
#define bse_int_seq_copy_shallow foo_prefix_bse_int_seq_copy_shallow
#define bse_int_seq_from_seq foo_prefix_bse_int_seq_from_seq
#define bse_int_seq_to_seq foo_prefix_bse_int_seq_to_seq
#define bse_int_seq_resize foo_prefix_bse_int_seq_resize
#define bse_int_seq_free foo_prefix_bse_int_seq_free
#define bse_note_seq_new foo_prefix_bse_note_seq_new
#define bse_note_seq_append foo_prefix_bse_note_seq_append
#define bse_note_seq_copy_shallow foo_prefix_bse_note_seq_copy_shallow
#define bse_note_seq_from_seq foo_prefix_bse_note_seq_from_seq
#define bse_note_seq_to_seq foo_prefix_bse_note_seq_to_seq
#define bse_note_seq_resize foo_prefix_bse_note_seq_resize
#define bse_note_seq_free foo_prefix_bse_note_seq_free
#define bse_string_seq_new foo_prefix_bse_string_seq_new
#define bse_string_seq_append foo_prefix_bse_string_seq_append
#define bse_string_seq_copy_shallow foo_prefix_bse_string_seq_copy_shallow
#define bse_string_seq_from_seq foo_prefix_bse_string_seq_from_seq
#define bse_string_seq_to_seq foo_prefix_bse_string_seq_to_seq
#define bse_string_seq_resize foo_prefix_bse_string_seq_resize
#define bse_string_seq_free foo_prefix_bse_string_seq_free
#define bse_proxy_seq_new foo_prefix_bse_proxy_seq_new
#define bse_proxy_seq_append foo_prefix_bse_proxy_seq_append
#define bse_proxy_seq_copy_shallow foo_prefix_bse_proxy_seq_copy_shallow
#define bse_proxy_seq_from_seq foo_prefix_bse_proxy_seq_from_seq
#define bse_proxy_seq_to_seq foo_prefix_bse_proxy_seq_to_seq
#define bse_proxy_seq_resize foo_prefix_bse_proxy_seq_resize
#define bse_proxy_seq_free foo_prefix_bse_proxy_seq_free
#define bse_part_note_seq_new foo_prefix_bse_part_note_seq_new
#define bse_part_note_seq_append foo_prefix_bse_part_note_seq_append
#define bse_part_note_seq_copy_shallow foo_prefix_bse_part_note_seq_copy_shallow
#define bse_part_note_seq_from_seq foo_prefix_bse_part_note_seq_from_seq
#define bse_part_note_seq_to_seq foo_prefix_bse_part_note_seq_to_seq
#define bse_part_note_seq_resize foo_prefix_bse_part_note_seq_resize
#define bse_part_note_seq_free foo_prefix_bse_part_note_seq_free
#define bse_category_seq_new foo_prefix_bse_category_seq_new
#define bse_category_seq_append foo_prefix_bse_category_seq_append
#define bse_category_seq_copy_shallow foo_prefix_bse_category_seq_copy_shallow
#define bse_category_seq_from_seq foo_prefix_bse_category_seq_from_seq
#define bse_category_seq_to_seq foo_prefix_bse_category_seq_to_seq
#define bse_category_seq_resize foo_prefix_bse_category_seq_resize
#define bse_category_seq_free foo_prefix_bse_category_seq_free
#define bse_dot_seq_new foo_prefix_bse_dot_seq_new
#define bse_dot_seq_append foo_prefix_bse_dot_seq_append
#define bse_dot_seq_copy_shallow foo_prefix_bse_dot_seq_copy_shallow
#define bse_dot_seq_from_seq foo_prefix_bse_dot_seq_from_seq
#define bse_dot_seq_to_seq foo_prefix_bse_dot_seq_to_seq
#define bse_dot_seq_resize foo_prefix_bse_dot_seq_resize
#define bse_dot_seq_free foo_prefix_bse_dot_seq_free
#define bse_track_part_seq_new foo_prefix_bse_track_part_seq_new
#define bse_track_part_seq_append foo_prefix_bse_track_part_seq_append
#define bse_track_part_seq_copy_shallow foo_prefix_bse_track_part_seq_copy_shallow
#define bse_track_part_seq_from_seq foo_prefix_bse_track_part_seq_from_seq
#define bse_track_part_seq_to_seq foo_prefix_bse_track_part_seq_to_seq
#define bse_track_part_seq_resize foo_prefix_bse_track_part_seq_resize
#define bse_track_part_seq_free foo_prefix_bse_track_part_seq_free
#define bse_part_note_new foo_prefix_bse_part_note_new
#define bse_part_note_copy_shallow foo_prefix_bse_part_note_copy_shallow
#define bse_part_note_from_rec foo_prefix_bse_part_note_from_rec
#define bse_part_note_to_rec foo_prefix_bse_part_note_to_rec
#define bse_part_note_free foo_prefix_bse_part_note_free
#define bse_note_description_new foo_prefix_bse_note_description_new
#define bse_note_description_copy_shallow foo_prefix_bse_note_description_copy_shallow
#define bse_note_description_from_rec foo_prefix_bse_note_description_from_rec
#define bse_note_description_to_rec foo_prefix_bse_note_description_to_rec
#define bse_note_description_free foo_prefix_bse_note_description_free
#define bse_note_sequence_new foo_prefix_bse_note_sequence_new
#define bse_note_sequence_copy_shallow foo_prefix_bse_note_sequence_copy_shallow
#define bse_note_sequence_from_rec foo_prefix_bse_note_sequence_from_rec
#define bse_note_sequence_to_rec foo_prefix_bse_note_sequence_to_rec
#define bse_note_sequence_free foo_prefix_bse_note_sequence_free
#define bse_icon_new foo_prefix_bse_icon_new
#define bse_icon_copy_shallow foo_prefix_bse_icon_copy_shallow
#define bse_icon_from_rec foo_prefix_bse_icon_from_rec
#define bse_icon_to_rec foo_prefix_bse_icon_to_rec
#define bse_icon_free foo_prefix_bse_icon_free
#define bse_category_new foo_prefix_bse_category_new
#define bse_category_copy_shallow foo_prefix_bse_category_copy_shallow
#define bse_category_from_rec foo_prefix_bse_category_from_rec
#define bse_category_to_rec foo_prefix_bse_category_to_rec
#define bse_category_free foo_prefix_bse_category_free
#define bse_dot_new foo_prefix_bse_dot_new
#define bse_dot_copy_shallow foo_prefix_bse_dot_copy_shallow
#define bse_dot_from_rec foo_prefix_bse_dot_from_rec
#define bse_dot_to_rec foo_prefix_bse_dot_to_rec
#define bse_dot_free foo_prefix_bse_dot_free
#define bse_track_part_new foo_prefix_bse_track_part_new
#define bse_track_part_copy_shallow foo_prefix_bse_track_part_copy_shallow
#define bse_track_part_from_rec foo_prefix_bse_track_part_from_rec
#define bse_track_part_to_rec foo_prefix_bse_track_part_to_rec
#define bse_track_part_free foo_prefix_bse_track_part_free
#define bse_song_timing_new foo_prefix_bse_song_timing_new
#define bse_song_timing_copy_shallow foo_prefix_bse_song_timing_copy_shallow
#define bse_song_timing_from_rec foo_prefix_bse_song_timing_from_rec
#define bse_song_timing_to_rec foo_prefix_bse_song_timing_to_rec
#define bse_song_timing_free foo_prefix_bse_song_timing_free
#define bse_gconfig_new foo_prefix_bse_gconfig_new
#define bse_gconfig_copy_shallow foo_prefix_bse_gconfig_copy_shallow
#define bse_gconfig_from_rec foo_prefix_bse_gconfig_from_rec
#define bse_gconfig_to_rec foo_prefix_bse_gconfig_to_rec
#define bse_gconfig_free foo_prefix_bse_gconfig_free
#define bse_registration_type_to_choice foo_prefix_bse_registration_type_to_choice
#define bse_registration_type_from_choice foo_prefix_bse_registration_type_from_choice
#define bse_user_msg_type_to_choice foo_prefix_bse_user_msg_type_to_choice
#define bse_user_msg_type_from_choice foo_prefix_bse_user_msg_type_from_choice
#define bse_error_type_to_choice foo_prefix_bse_error_type_to_choice
#define bse_error_type_from_choice foo_prefix_bse_error_type_from_choice
#define bse_project_state_to_choice foo_prefix_bse_project_state_to_choice
#define bse_project_state_from_choice foo_prefix_bse_project_state_from_choice
#define bse_item_check_is_a foo_prefix_bse_item_check_is_a
#define bse_item_common_ancestor foo_prefix_bse_item_common_ancestor
#define bse_item_fixme_get_parasite foo_prefix_bse_item_fixme_get_parasite
#define bse_item_fixme_set_parasite foo_prefix_bse_item_fixme_set_parasite
#define bse_item_get_icon foo_prefix_bse_item_get_icon
#define bse_item_get_name foo_prefix_bse_item_get_name
#define bse_item_get_name_or_type foo_prefix_bse_item_get_name_or_type
#define bse_item_get_parent foo_prefix_bse_item_get_parent
#define bse_item_get_project foo_prefix_bse_item_get_project
#define bse_item_get_seqid foo_prefix_bse_item_get_seqid
#define bse_item_get_type foo_prefix_bse_item_get_type
#define bse_item_get_type_blurb foo_prefix_bse_item_get_type_blurb
#define bse_item_get_type_name foo_prefix_bse_item_get_type_name
#define bse_item_get_uname_path foo_prefix_bse_item_get_uname_path
#define bse_item_list_proxies foo_prefix_bse_item_list_proxies
#define bse_item_set_name foo_prefix_bse_item_set_name
#define bse_item_unuse foo_prefix_bse_item_unuse
#define bse_item_use foo_prefix_bse_item_use
#define bse_source_clear_inputs foo_prefix_bse_source_clear_inputs
#define bse_source_clear_outputs foo_prefix_bse_source_clear_outputs
#define bse_source_has_outputs foo_prefix_bse_source_has_outputs
#define bse_source_ichannel_blurb foo_prefix_bse_source_ichannel_blurb
#define bse_source_ichannel_get_n_joints foo_prefix_bse_source_ichannel_get_n_joints
#define bse_source_ichannel_get_ochannel foo_prefix_bse_source_ichannel_get_ochannel
#define bse_source_ichannel_get_osource foo_prefix_bse_source_ichannel_get_osource
#define bse_source_ichannel_ident foo_prefix_bse_source_ichannel_ident
#define bse_source_ichannel_name foo_prefix_bse_source_ichannel_name
#define bse_source_is_joint_ichannel foo_prefix_bse_source_is_joint_ichannel
#define bse_source_is_joint_ichannel_by_id foo_prefix_bse_source_is_joint_ichannel_by_id
#define bse_source_n_ichannels foo_prefix_bse_source_n_ichannels
#define bse_source_n_ochannels foo_prefix_bse_source_n_ochannels
#define bse_source_ochannel_blurb foo_prefix_bse_source_ochannel_blurb
#define bse_source_ochannel_ident foo_prefix_bse_source_ochannel_ident
#define bse_source_ochannel_name foo_prefix_bse_source_ochannel_name
#define bse_source_set_input foo_prefix_bse_source_set_input
#define bse_source_set_input_by_id foo_prefix_bse_source_set_input_by_id
#define bse_source_unset_input foo_prefix_bse_source_unset_input
#define bse_source_unset_input_by_id foo_prefix_bse_source_unset_input_by_id
#define bse_container_get_item foo_prefix_bse_container_get_item
#define bse_container_list_items foo_prefix_bse_container_list_items
#define bse_container_lookup_item foo_prefix_bse_container_lookup_item
#define bse_wave_repo_load_file foo_prefix_bse_wave_repo_load_file
#define bse_wave_repo_remove_wave foo_prefix_bse_wave_repo_remove_wave
#define bse_snet_can_create_source foo_prefix_bse_snet_can_create_source
#define bse_snet_create_source foo_prefix_bse_snet_create_source
#define bse_snet_remove_source foo_prefix_bse_snet_remove_source
#define bse_snet_supports_user_synths foo_prefix_bse_snet_supports_user_synths
#define bse_song_create_part foo_prefix_bse_song_create_part
#define bse_song_create_track foo_prefix_bse_song_create_track
#define bse_song_find_track_for_part foo_prefix_bse_song_find_track_for_part
#define bse_song_get_timing foo_prefix_bse_song_get_timing
#define bse_song_remove_part foo_prefix_bse_song_remove_part
#define bse_song_remove_track foo_prefix_bse_song_remove_track
#define bse_song_synthesize_note foo_prefix_bse_song_synthesize_note
#define bse_project_restore_from_file foo_prefix_bse_project_restore_from_file
#define bse_project_store_bse foo_prefix_bse_project_store_bse
#define bse_project_activate foo_prefix_bse_project_activate
#define bse_project_auto_deactivate foo_prefix_bse_project_auto_deactivate
#define bse_project_can_play foo_prefix_bse_project_can_play
#define bse_project_create_midi_synth foo_prefix_bse_project_create_midi_synth
#define bse_project_create_snet foo_prefix_bse_project_create_snet
#define bse_project_create_song foo_prefix_bse_project_create_song
#define bse_project_deactivate foo_prefix_bse_project_deactivate
#define bse_project_ensure_wave_repo foo_prefix_bse_project_ensure_wave_repo
#define bse_project_find_item foo_prefix_bse_project_find_item
#define bse_project_get_data_pocket foo_prefix_bse_project_get_data_pocket
#define bse_project_get_state foo_prefix_bse_project_get_state
#define bse_project_get_supers foo_prefix_bse_project_get_supers
#define bse_project_is_playing foo_prefix_bse_project_is_playing
#define bse_project_list_uname_paths foo_prefix_bse_project_list_uname_paths
#define bse_project_match_items_by_uname foo_prefix_bse_project_match_items_by_uname
#define bse_project_play foo_prefix_bse_project_play
#define bse_project_start_playback foo_prefix_bse_project_start_playback
#define bse_project_stop foo_prefix_bse_project_stop
#define bse_project_stop_playback foo_prefix_bse_project_stop_playback
#define bse_server_can_load foo_prefix_bse_server_can_load
#define bse_server_construct_note foo_prefix_bse_server_construct_note
#define bse_server_describe_note foo_prefix_bse_server_describe_note
#define bse_server_get_midi_notifier foo_prefix_bse_server_get_midi_notifier
#define bse_server_n_scripts foo_prefix_bse_server_n_scripts
#define bse_server_note_from_freq foo_prefix_bse_server_note_from_freq
#define bse_server_note_from_string foo_prefix_bse_server_note_from_string
#define bse_server_preferences_locked foo_prefix_bse_server_preferences_locked
#define bse_server_register_plugins foo_prefix_bse_server_register_plugins
#define bse_server_register_scripts foo_prefix_bse_server_register_scripts
#define bse_server_save_preferences foo_prefix_bse_server_save_preferences
#define bse_server_use_new_project foo_prefix_bse_server_use_new_project
#define bse_wave_osc_pcm_seek_perc foo_prefix_bse_wave_osc_pcm_seek_perc
#define bse_wave_osc_request_pcm_position foo_prefix_bse_wave_osc_request_pcm_position
#define bse_wave_chunk_get_mix_freq foo_prefix_bse_wave_chunk_get_mix_freq
#define bse_wave_chunk_get_osc_freq foo_prefix_bse_wave_chunk_get_osc_freq
#define bse_wave_load_wave foo_prefix_bse_wave_load_wave
#define bse_wave_n_wave_chunks foo_prefix_bse_wave_n_wave_chunks
#define bse_wave_use_editable foo_prefix_bse_wave_use_editable
#define bse_midi_notifier_current_time foo_prefix_bse_midi_notifier_current_time
#define bse_track_get_part foo_prefix_bse_track_get_part
#define bse_track_get_timing foo_prefix_bse_track_get_timing
#define bse_track_insert_part foo_prefix_bse_track_insert_part
#define bse_track_list_parts foo_prefix_bse_track_list_parts
#define bse_track_remove_tick foo_prefix_bse_track_remove_tick
#define bse_part_change_note foo_prefix_bse_part_change_note
#define bse_part_check_overlap foo_prefix_bse_part_check_overlap
#define bse_part_delete_event foo_prefix_bse_part_delete_event
#define bse_part_deselect_event foo_prefix_bse_part_deselect_event
#define bse_part_deselect_rectangle foo_prefix_bse_part_deselect_rectangle
#define bse_part_get_max_note foo_prefix_bse_part_get_max_note
#define bse_part_get_max_tick foo_prefix_bse_part_get_max_tick
#define bse_part_get_min_note foo_prefix_bse_part_get_min_note
#define bse_part_get_notes foo_prefix_bse_part_get_notes
#define bse_part_get_timing foo_prefix_bse_part_get_timing
#define bse_part_insert_note foo_prefix_bse_part_insert_note
#define bse_part_is_selected_event foo_prefix_bse_part_is_selected_event
#define bse_part_list_notes_crossing foo_prefix_bse_part_list_notes_crossing
#define bse_part_list_selected_notes foo_prefix_bse_part_list_selected_notes
#define bse_part_queue_notes_within foo_prefix_bse_part_queue_notes_within
#define bse_part_select_event foo_prefix_bse_part_select_event
#define bse_part_select_rectangle foo_prefix_bse_part_select_rectangle
#define bse_part_select_rectangle_exclusive foo_prefix_bse_part_select_rectangle_exclusive
#define bse_data_pocket_create_entry foo_prefix_bse_data_pocket_create_entry
#define bse_data_pocket_delete_entry foo_prefix_bse_data_pocket_delete_entry
#define bse_data_pocket_get_float foo_prefix_bse_data_pocket_get_float
#define bse_data_pocket_get_int foo_prefix_bse_data_pocket_get_int
#define bse_data_pocket_get_n_entries foo_prefix_bse_data_pocket_get_n_entries
#define bse_data_pocket_get_nth_entry_id foo_prefix_bse_data_pocket_get_nth_entry_id
#define bse_data_pocket_get_object foo_prefix_bse_data_pocket_get_object
#define bse_data_pocket_get_string foo_prefix_bse_data_pocket_get_string
#define bse_data_pocket_set_float foo_prefix_bse_data_pocket_set_float
#define bse_data_pocket_set_int foo_prefix_bse_data_pocket_set_int
#define bse_data_pocket_set_object foo_prefix_bse_data_pocket_set_object
#define bse_data_pocket_set_string foo_prefix_bse_data_pocket_set_string
#define bse_janitor_add_action foo_prefix_bse_janitor_add_action
#define bse_janitor_exit foo_prefix_bse_janitor_exit
#define bse_janitor_get_action foo_prefix_bse_janitor_get_action
#define bse_janitor_get_action_blurb foo_prefix_bse_janitor_get_action_blurb
#define bse_janitor_get_action_name foo_prefix_bse_janitor_get_action_name
#define bse_janitor_get_proc_name foo_prefix_bse_janitor_get_proc_name
#define bse_janitor_get_script_name foo_prefix_bse_janitor_get_script_name
#define bse_janitor_kill foo_prefix_bse_janitor_kill
#define bse_janitor_n_actions foo_prefix_bse_janitor_n_actions
#define bse_janitor_progress foo_prefix_bse_janitor_progress
#define bse_janitor_remove_action foo_prefix_bse_janitor_remove_action
#define bse_janitor_set_msg foo_prefix_bse_janitor_set_msg
#define bse_janitor_trigger_action foo_prefix_bse_janitor_trigger_action
#define bse_editable_sample_close foo_prefix_bse_editable_sample_close
#define bse_editable_sample_collect_stats foo_prefix_bse_editable_sample_collect_stats
#define bse_editable_sample_get_length foo_prefix_bse_editable_sample_get_length
#define bse_editable_sample_get_n_channels foo_prefix_bse_editable_sample_get_n_channels
#define bse_editable_sample_get_osc_freq foo_prefix_bse_editable_sample_get_osc_freq
#define bse_editable_sample_open foo_prefix_bse_editable_sample_open
#define bse_editable_sample_read_samples foo_prefix_bse_editable_sample_read_samples
#define bse_janitor_get_specific foo_prefix_bse_janitor_get_specific
#define bse_hello_world foo_prefix_bse_hello_world
#define bse_randomizer foo_prefix_bse_randomizer
#define bse_category_from_id foo_prefix_bse_category_from_id
#define bse_categories_match foo_prefix_bse_categories_match
#define bse_categories_match_typed foo_prefix_bse_categories_match_typed
#define bse_error_blurb foo_prefix_bse_error_blurb
#define bse_error_name foo_prefix_bse_error_name
#define bse_proxy_check foo_prefix_bse_proxy_check
#define bse_note_from_freq foo_prefix_bse_note_from_freq
#define bse_note_to_freq foo_prefix_bse_note_to_freq
#define bse_type_blurb foo_prefix_bse_type_blurb

typedef struct _BseIntSeq BseIntSeq;
typedef struct _BseNoteSeq BseNoteSeq;
typedef struct _BseStringSeq BseStringSeq;
typedef struct _BseProxySeq BseProxySeq;
typedef struct _BsePartNoteSeq BsePartNoteSeq;
typedef struct _BseCategorySeq BseCategorySeq;
typedef struct _BseDotSeq BseDotSeq;
typedef struct _BseTrackPartSeq BseTrackPartSeq;
typedef struct _BsePartNote BsePartNote;
typedef struct _BseNoteDescription BseNoteDescription;
typedef struct _BseNoteSequence BseNoteSequence;
typedef struct _BseIcon BseIcon;
typedef struct _BseCategory BseCategory;
typedef struct _BseDot BseDot;
typedef struct _BseTrackPart BseTrackPart;
typedef struct _BseSongTiming BseSongTiming;
typedef struct _BseGConfig BseGConfig;

typedef enum {
  BSE_REGISTER_PLUGIN = 1,
  BSE_REGISTER_SCRIPT = 2,
  BSE_REGISTER_DONE = 3,
} BseRegistrationType;
const gchar* bse_registration_type_to_choice (BseRegistrationType value);
BseRegistrationType bse_registration_type_from_choice (const gchar *choice);

typedef enum {
  BSE_USER_MSG_INFO = 1,
  BSE_USER_MSG_QUESTION = 2,
  BSE_USER_MSG_WARNING = 3,
  BSE_USER_MSG_ERROR = 4,
} BseUserMsgType;
const gchar* bse_user_msg_type_to_choice (BseUserMsgType value);
BseUserMsgType bse_user_msg_type_from_choice (const gchar *choice);

typedef enum {
  BSE_ERROR_NONE = 0,
  BSE_ERROR_INTERNAL = 1,
  BSE_ERROR_UNKNOWN = 2,
  BSE_ERROR_FILE_IO = 3,
  BSE_ERROR_FILE_PERMS = 4,
  BSE_ERROR_FILE_BUSY = 5,
  BSE_ERROR_FILE_EXISTS = 6,
  BSE_ERROR_FILE_EOF = 7,
  BSE_ERROR_FILE_NOT_FOUND = 8,
  BSE_ERROR_FILE_OPEN_FAILED = 9,
  BSE_ERROR_FILE_SEEK_FAILED = 10,
  BSE_ERROR_FILE_READ_FAILED = 11,
  BSE_ERROR_FILE_WRITE_FAILED = 12,
  BSE_ERROR_MANY_FILES = 13,
  BSE_ERROR_NO_FILES = 14,
  BSE_ERROR_NO_SPACE = 15,
  BSE_ERROR_NO_MEMORY = 16,
  BSE_ERROR_NO_HEADER = 17,
  BSE_ERROR_NO_SEEK_INFO = 18,
  BSE_ERROR_NO_DATA = 19,
  BSE_ERROR_DATA_CORRUPT = 20,
  BSE_ERROR_FORMAT_INVALID = 21,
  BSE_ERROR_FORMAT_UNKNOWN = 22,
  BSE_ERROR_TEMP = 23,
  BSE_ERROR_WAVE_NOT_FOUND = 24,
  BSE_ERROR_CODEC_FAILURE = 25,
  BSE_ERROR_UNIMPLEMENTED = 26,
  BSE_ERROR_DEVICE_NOT_AVAILABLE = 27,
  BSE_ERROR_DEVICE_ASYNC = 28,
  BSE_ERROR_DEVICE_BUSY = 29,
  BSE_ERROR_DEVICE_GET_CAPS = 30,
  BSE_ERROR_DEVICE_CAPS_MISMATCH = 31,
  BSE_ERROR_DEVICE_SET_CAPS = 32,
  BSE_ERROR_DATE_INVALID = 33,
  BSE_ERROR_DATE_CLUTTERED = 34,
  BSE_ERROR_DATE_YEAR_BOUNDS = 35,
  BSE_ERROR_DATE_MONTH_BOUNDS = 36,
  BSE_ERROR_DATE_DAY_BOUNDS = 37,
  BSE_ERROR_DATE_HOUR_BOUNDS = 38,
  BSE_ERROR_DATE_MINUTE_BOUNDS = 39,
  BSE_ERROR_DATE_SECOND_BOUNDS = 40,
  BSE_ERROR_DATE_TOO_OLD = 41,
  BSE_ERROR_SOURCE_NO_SUCH_MODULE = 42,
  BSE_ERROR_SOURCE_NO_SUCH_ICHANNEL = 43,
  BSE_ERROR_SOURCE_NO_SUCH_OCHANNEL = 44,
  BSE_ERROR_SOURCE_NO_SUCH_CONNECTION = 45,
  BSE_ERROR_SOURCE_ICHANNEL_IN_USE = 46,
  BSE_ERROR_SOURCE_CHANNELS_CONNECTED = 47,
  BSE_ERROR_SOURCE_BAD_LOOPBACK = 48,
  BSE_ERROR_SOURCE_BUSY = 49,
  BSE_ERROR_SOURCE_TYPE_INVALID = 50,
  BSE_ERROR_PROC_NOT_FOUND = 51,
  BSE_ERROR_PROC_BUSY = 52,
  BSE_ERROR_PROC_PARAM_INVAL = 53,
  BSE_ERROR_PROC_EXECUTION = 54,
  BSE_ERROR_PROC_ABORT = 55,
  BSE_ERROR_PARSE_ERROR = 56,
  BSE_ERROR_SPAWN = 57,
  BSE_ERROR_POS_ALLOC = 58,
  BSE_ERROR_NO_ENTRY = 59,
  BSE_ERROR_NO_EVENT = 60,
  BSE_ERROR_NO_TARGET = 61,
  BSE_ERROR_NOT_OWNER = 62,
  BSE_ERROR_INVALID_OFFSET = 63,
  BSE_ERROR_INVALID_DURATION = 64,
  BSE_ERROR_INVALID_OVERLAP = 65,
} BseErrorType;
const gchar* bse_error_type_to_choice (BseErrorType value);
BseErrorType bse_error_type_from_choice (const gchar *choice);

typedef enum {
  BSE_PROJECT_INACTIVE = 1,
  BSE_PROJECT_ACTIVE = 2,
  BSE_PROJECT_PLAYING = 3,
} BseProjectState;
const gchar* bse_project_state_to_choice (BseProjectState value);
BseProjectState bse_project_state_from_choice (const gchar *choice);

struct _BseIntSeq {
  guint n_ints;
  SfiInt* ints;
};
struct _BseNoteSeq {
  guint n_notes;
  SfiInt* notes;
};
struct _BseStringSeq {
  guint n_strings;
  gchar** strings;
};
struct _BseProxySeq {
  guint n_proxies;
  SfiProxy* proxies;
};
struct _BsePartNoteSeq {
  guint n_pnotes;
  BsePartNote** pnotes;
};
struct _BseCategorySeq {
  guint n_cats;
  BseCategory** cats;
};
struct _BseDotSeq {
  guint n_dots;
  BseDot** dots;
};
struct _BseTrackPartSeq {
  guint n_tparts;
  BseTrackPart** tparts;
};
struct _BsePartNote {
  SfiInt id;
  SfiInt tick;
  SfiInt duration;
  SfiInt note;
  SfiInt fine_tune;
  SfiReal velocity;
  SfiBool selected;
};
struct _BseNoteDescription {
  SfiInt note;
  SfiInt octave;
  SfiReal freq;
  SfiInt fine_tune;
  SfiInt semitone;
  SfiBool upshift;
  SfiInt letter;
  gchar* name;
  SfiInt max_fine_tune;
  SfiInt kammer_note;
};
struct _BseNoteSequence {
  SfiInt offset;
  BseNoteSeq* notes;
};
struct _BseIcon {
  SfiInt bytes_per_pixel;
  SfiInt width;
  SfiInt height;
  SfiBBlock* pixels;
};
struct _BseCategory {
  SfiInt category_id;
  gchar* category;
  SfiInt mindex;
  SfiInt lindex;
  gchar* type;
  BseIcon* icon;
};
struct _BseDot {
  SfiReal x;
  SfiReal y;
};
struct _BseTrackPart {
  SfiInt tick;
  SfiProxy part;
  SfiInt duration;
};
struct _BseSongTiming {
  SfiInt tick;
  SfiReal bpm;
  SfiInt nominator;
  SfiInt denominator;
  SfiInt tpqn;
  SfiInt tpt;
};
struct _BseGConfig {
  SfiInt synth_block_size;
  SfiInt synth_mixing_freq;
  SfiBool invert_sustain;
  SfiReal step_volume_dB;
  SfiInt step_bpm;
};

BseIntSeq* bse_int_seq_new (void);
void bse_int_seq_append (BseIntSeq* seq, SfiInt element);
BseIntSeq* bse_int_seq_copy_shallow (BseIntSeq* seq);
BseIntSeq* bse_int_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_int_seq_to_seq (BseIntSeq* seq);
void bse_int_seq_resize (BseIntSeq* seq, guint new_size);
void bse_int_seq_free (BseIntSeq* seq);

BseNoteSeq* bse_note_seq_new (void);
void bse_note_seq_append (BseNoteSeq* seq, SfiInt element);
BseNoteSeq* bse_note_seq_copy_shallow (BseNoteSeq* seq);
BseNoteSeq* bse_note_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_note_seq_to_seq (BseNoteSeq* seq);
void bse_note_seq_resize (BseNoteSeq* seq, guint new_size);
void bse_note_seq_free (BseNoteSeq* seq);

BseStringSeq* bse_string_seq_new (void);
void bse_string_seq_append (BseStringSeq* seq, const gchar* element);
BseStringSeq* bse_string_seq_copy_shallow (BseStringSeq* seq);
BseStringSeq* bse_string_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_string_seq_to_seq (BseStringSeq* seq);
void bse_string_seq_resize (BseStringSeq* seq, guint new_size);
void bse_string_seq_free (BseStringSeq* seq);

BseProxySeq* bse_proxy_seq_new (void);
void bse_proxy_seq_append (BseProxySeq* seq, SfiProxy element);
BseProxySeq* bse_proxy_seq_copy_shallow (BseProxySeq* seq);
BseProxySeq* bse_proxy_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_proxy_seq_to_seq (BseProxySeq* seq);
void bse_proxy_seq_resize (BseProxySeq* seq, guint new_size);
void bse_proxy_seq_free (BseProxySeq* seq);

BsePartNoteSeq* bse_part_note_seq_new (void);
void bse_part_note_seq_append (BsePartNoteSeq* seq, BsePartNote* element);
BsePartNoteSeq* bse_part_note_seq_copy_shallow (BsePartNoteSeq* seq);
BsePartNoteSeq* bse_part_note_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_part_note_seq_to_seq (BsePartNoteSeq* seq);
void bse_part_note_seq_resize (BsePartNoteSeq* seq, guint new_size);
void bse_part_note_seq_free (BsePartNoteSeq* seq);

BseCategorySeq* bse_category_seq_new (void);
void bse_category_seq_append (BseCategorySeq* seq, BseCategory* element);
BseCategorySeq* bse_category_seq_copy_shallow (BseCategorySeq* seq);
BseCategorySeq* bse_category_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_category_seq_to_seq (BseCategorySeq* seq);
void bse_category_seq_resize (BseCategorySeq* seq, guint new_size);
void bse_category_seq_free (BseCategorySeq* seq);

BseDotSeq* bse_dot_seq_new (void);
void bse_dot_seq_append (BseDotSeq* seq, BseDot* element);
BseDotSeq* bse_dot_seq_copy_shallow (BseDotSeq* seq);
BseDotSeq* bse_dot_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_dot_seq_to_seq (BseDotSeq* seq);
void bse_dot_seq_resize (BseDotSeq* seq, guint new_size);
void bse_dot_seq_free (BseDotSeq* seq);

BseTrackPartSeq* bse_track_part_seq_new (void);
void bse_track_part_seq_append (BseTrackPartSeq* seq, BseTrackPart* element);
BseTrackPartSeq* bse_track_part_seq_copy_shallow (BseTrackPartSeq* seq);
BseTrackPartSeq* bse_track_part_seq_from_seq (SfiSeq *sfi_seq);
SfiSeq *bse_track_part_seq_to_seq (BseTrackPartSeq* seq);
void bse_track_part_seq_resize (BseTrackPartSeq* seq, guint new_size);
void bse_track_part_seq_free (BseTrackPartSeq* seq);

BsePartNote* bse_part_note_new (void);
BsePartNote* bse_part_note_copy_shallow (BsePartNote* rec);
BsePartNote* bse_part_note_from_rec (SfiRec *sfi_rec);
SfiRec *bse_part_note_to_rec (BsePartNote* rec);
void bse_part_note_free (BsePartNote* rec);

BseNoteDescription* bse_note_description_new (void);
BseNoteDescription* bse_note_description_copy_shallow (BseNoteDescription* rec);
BseNoteDescription* bse_note_description_from_rec (SfiRec *sfi_rec);
SfiRec *bse_note_description_to_rec (BseNoteDescription* rec);
void bse_note_description_free (BseNoteDescription* rec);

BseNoteSequence* bse_note_sequence_new (void);
BseNoteSequence* bse_note_sequence_copy_shallow (BseNoteSequence* rec);
BseNoteSequence* bse_note_sequence_from_rec (SfiRec *sfi_rec);
SfiRec *bse_note_sequence_to_rec (BseNoteSequence* rec);
void bse_note_sequence_free (BseNoteSequence* rec);

BseIcon* bse_icon_new (void);
BseIcon* bse_icon_copy_shallow (BseIcon* rec);
BseIcon* bse_icon_from_rec (SfiRec *sfi_rec);
SfiRec *bse_icon_to_rec (BseIcon* rec);
void bse_icon_free (BseIcon* rec);

BseCategory* bse_category_new (void);
BseCategory* bse_category_copy_shallow (BseCategory* rec);
BseCategory* bse_category_from_rec (SfiRec *sfi_rec);
SfiRec *bse_category_to_rec (BseCategory* rec);
void bse_category_free (BseCategory* rec);

BseDot* bse_dot_new (void);
BseDot* bse_dot_copy_shallow (BseDot* rec);
BseDot* bse_dot_from_rec (SfiRec *sfi_rec);
SfiRec *bse_dot_to_rec (BseDot* rec);
void bse_dot_free (BseDot* rec);

BseTrackPart* bse_track_part_new (void);
BseTrackPart* bse_track_part_copy_shallow (BseTrackPart* rec);
BseTrackPart* bse_track_part_from_rec (SfiRec *sfi_rec);
SfiRec *bse_track_part_to_rec (BseTrackPart* rec);
void bse_track_part_free (BseTrackPart* rec);

BseSongTiming* bse_song_timing_new (void);
BseSongTiming* bse_song_timing_copy_shallow (BseSongTiming* rec);
BseSongTiming* bse_song_timing_from_rec (SfiRec *sfi_rec);
SfiRec *bse_song_timing_to_rec (BseSongTiming* rec);
void bse_song_timing_free (BseSongTiming* rec);

BseGConfig* bse_gconfig_new (void);
BseGConfig* bse_gconfig_copy_shallow (BseGConfig* rec);
BseGConfig* bse_gconfig_from_rec (SfiRec *sfi_rec);
SfiRec *bse_gconfig_to_rec (BseGConfig* rec);
void bse_gconfig_free (BseGConfig* rec);


extern SfiChoiceValues bse_registration_type_values;
extern SfiChoiceValues bse_user_msg_type_values;
extern SfiChoiceValues bse_error_type_values;
extern SfiChoiceValues bse_project_state_values;
extern SfiRecFields bse_part_note_fields;
extern SfiRecFields bse_note_description_fields;
extern SfiRecFields bse_note_sequence_fields;
extern SfiRecFields bse_icon_fields;
extern SfiRecFields bse_category_fields;
extern SfiRecFields bse_dot_fields;
extern SfiRecFields bse_track_part_fields;
extern SfiRecFields bse_song_timing_fields;
extern SfiRecFields bse_gconfig_fields;

#define BSE_IS_ITEM(proxy) bse_proxy_is_a ((proxy), "BseItem")
#define BSE_IS_SOURCE(proxy) bse_proxy_is_a ((proxy), "BseSource")
#define BSE_IS_SNOOPER(proxy) bse_proxy_is_a ((proxy), "BseSnooper")
#define BSE_IS_CONSTANT(proxy) bse_proxy_is_a ((proxy), "BseConstant")
#define BSE_IS_CONTAINER(proxy) bse_proxy_is_a ((proxy), "BseContainer")
#define BSE_IS_SUPER(proxy) bse_proxy_is_a ((proxy), "BseSuper")
#define BSE_IS_WAVE_REPO(proxy) bse_proxy_is_a ((proxy), "BseWaveRepo")
#define BSE_IS_SNET(proxy) bse_proxy_is_a ((proxy), "BseSNet")
#define BSE_IS_MIDI_SYNTH(proxy) bse_proxy_is_a ((proxy), "BseMidiSynth")
#define BSE_IS_SONG(proxy) bse_proxy_is_a ((proxy), "BseSong")
#define BSE_IS_PROJECT(proxy) bse_proxy_is_a ((proxy), "BseProject")
#define BSE_IS_SERVER(proxy) bse_proxy_is_a ((proxy), "BseServer")
#define BSE_IS_WAVE_OSC(proxy) bse_proxy_is_a ((proxy), "BseWaveOsc")
#define BSE_IS_MIDI_ICONTROLLER(proxy) bse_proxy_is_a ((proxy), "BseMidiIController")
#define BSE_IS_MIDI_VOICE_INPUT(proxy) bse_proxy_is_a ((proxy), "BseMidiVoiceInput")
#define BSE_IS_CONTEXT_MERGER(proxy) bse_proxy_is_a ((proxy), "BseContextMerger")
#define BSE_IS_SUB_IPORT(proxy) bse_proxy_is_a ((proxy), "BseSubIPort")
#define BSE_IS_SUB_KEYBOARD(proxy) bse_proxy_is_a ((proxy), "BseSubKeyboard")
#define BSE_IS_BIQUAD_FILTER(proxy) bse_proxy_is_a ((proxy), "BseBiquadFilter")
#define BSE_IS_SUB_SYNTH(proxy) bse_proxy_is_a ((proxy), "BseSubSynth")
#define BSE_IS_STANDARD_OSC(proxy) bse_proxy_is_a ((proxy), "BseStandardOsc")
#define BSE_IS_PCM_OUTPUT(proxy) bse_proxy_is_a ((proxy), "BsePcmOutput")
#define BSE_IS_PCM_INPUT(proxy) bse_proxy_is_a ((proxy), "BsePcmInput")
#define BSE_IS_SUB_OPORT(proxy) bse_proxy_is_a ((proxy), "BseSubOPort")
#define BSE_IS_SUB_INSTRUMENT(proxy) bse_proxy_is_a ((proxy), "BseSubInstrument")
#define BSE_IS_WAVE(proxy) bse_proxy_is_a ((proxy), "BseWave")
#define BSE_IS_MIDI_VOICE_SWITCH(proxy) bse_proxy_is_a ((proxy), "BseMidiVoiceSwitch")
#define BSE_IS_LADSPA_MODULE(proxy) bse_proxy_is_a ((proxy), "BseLadspaModule")
#define BSE_IS_AMPLIFIER(proxy) bse_proxy_is_a ((proxy), "BseAmplifier")
#define BSE_IS_MIDI_NOTIFIER(proxy) bse_proxy_is_a ((proxy), "BseMidiNotifier")
#define BSE_IS_TRACK(proxy) bse_proxy_is_a ((proxy), "BseTrack")
#define BSE_IS_PART(proxy) bse_proxy_is_a ((proxy), "BsePart")
#define BSE_IS_DATA_POCKET(proxy) bse_proxy_is_a ((proxy), "BseDataPocket")
#define BSE_IS_JANITOR(proxy) bse_proxy_is_a ((proxy), "BseJanitor")
#define BSE_IS_EDITABLE_SAMPLE(proxy) bse_proxy_is_a ((proxy), "BseEditableSample")
#define BSE_IS_PCM_DEVICE(proxy) bse_proxy_is_a ((proxy), "BsePcmDevice")
#define BSE_IS_PCM_DEVICE_OSS(proxy) bse_proxy_is_a ((proxy), "BsePcmDeviceOSS")

SfiBool bse_item_check_is_a (SfiProxy bse_item_object, const gchar* type_name);
SfiProxy bse_item_common_ancestor (SfiProxy bse_item_object, SfiProxy item2);
SfiFBlock* bse_item_fixme_get_parasite (SfiProxy bse_item_object, const gchar* name);
void bse_item_fixme_set_parasite (SfiProxy bse_item_object, const gchar* name, SfiFBlock* parasite);
BseIcon* bse_item_get_icon (SfiProxy bse_item_object);
const gchar* bse_item_get_name (SfiProxy bse_item_object);
const gchar* bse_item_get_name_or_type (SfiProxy bse_item_object);
SfiProxy bse_item_get_parent (SfiProxy bse_item_object);
SfiProxy bse_item_get_project (SfiProxy bse_item_object);
SfiInt bse_item_get_seqid (SfiProxy bse_item_object);
const gchar* bse_item_get_type (SfiProxy bse_item_object);
const gchar* bse_item_get_type_blurb (SfiProxy bse_item_object);
const gchar* bse_item_get_type_name (SfiProxy bse_item_object);
const gchar* bse_item_get_uname_path (SfiProxy bse_item_object);
BseProxySeq* bse_item_list_proxies (SfiProxy bse_item_object, const gchar* property_name);
void bse_item_set_name (SfiProxy bse_item_object, const gchar* name);
void bse_item_unuse (SfiProxy bse_item_object);
SfiProxy bse_item_use (SfiProxy bse_item_object);
void bse_source_clear_inputs (SfiProxy bse_source_object);
void bse_source_clear_outputs (SfiProxy bse_source_object);
SfiBool bse_source_has_outputs (SfiProxy bse_source_object);
const gchar* bse_source_ichannel_blurb (SfiProxy bse_source_object, SfiInt input_channel);
SfiInt bse_source_ichannel_get_n_joints (SfiProxy bse_source_object, SfiInt input_channel);
SfiInt bse_source_ichannel_get_ochannel (SfiProxy bse_source_object, SfiInt input_channel, SfiInt input_joint);
SfiProxy bse_source_ichannel_get_osource (SfiProxy bse_source_object, SfiInt input_channel, SfiInt input_joint);
const gchar* bse_source_ichannel_ident (SfiProxy bse_source_object, SfiInt input_channel);
const gchar* bse_source_ichannel_name (SfiProxy bse_source_object, SfiInt input_channel);
SfiBool bse_source_is_joint_ichannel (SfiProxy bse_source_object, const gchar* input_channel);
SfiBool bse_source_is_joint_ichannel_by_id (SfiProxy bse_source_object, SfiInt input_channel);
SfiInt bse_source_n_ichannels (SfiProxy bse_source_object);
SfiInt bse_source_n_ochannels (SfiProxy bse_source_object);
const gchar* bse_source_ochannel_blurb (SfiProxy bse_source_object, SfiInt input_channel);
const gchar* bse_source_ochannel_ident (SfiProxy bse_source_object, SfiInt input_channel);
const gchar* bse_source_ochannel_name (SfiProxy bse_source_object, SfiInt input_channel);
BseErrorType bse_source_set_input (SfiProxy bse_source_object, const gchar* input_channel, SfiProxy omodule, const gchar* output_channel);
BseErrorType bse_source_set_input_by_id (SfiProxy bse_source_object, SfiInt input_channel, SfiProxy omodule, SfiInt output_channel);
BseErrorType bse_source_unset_input (SfiProxy bse_source_object, const gchar* input_channel, SfiProxy omodule, const gchar* output_channel);
BseErrorType bse_source_unset_input_by_id (SfiProxy bse_source_object, SfiInt input_channel, SfiProxy omodule, SfiInt output_channel);
SfiProxy bse_container_get_item (SfiProxy bse_container_object, const gchar* item_type, SfiInt seq_id);
BseProxySeq* bse_container_list_items (SfiProxy bse_container_object);
SfiProxy bse_container_lookup_item (SfiProxy bse_container_object, const gchar* uname);
BseErrorType bse_wave_repo_load_file (SfiProxy bse_wave_repo_object, const gchar* file_name);
void bse_wave_repo_remove_wave (SfiProxy bse_wave_repo_object, SfiProxy wave);
BseErrorType bse_snet_can_create_source (SfiProxy bse_snet_object, const gchar* module_type);
SfiProxy bse_snet_create_source (SfiProxy bse_snet_object, const gchar* module_type);
BseErrorType bse_snet_remove_source (SfiProxy bse_snet_object, SfiProxy module);
SfiBool bse_snet_supports_user_synths (SfiProxy bse_snet_object);
SfiProxy bse_song_create_part (SfiProxy bse_song_object);
SfiProxy bse_song_create_track (SfiProxy bse_song_object);
SfiProxy bse_song_find_track_for_part (SfiProxy bse_song_object, SfiProxy part);
BseSongTiming* bse_song_get_timing (SfiProxy bse_song_object, SfiInt tick);
void bse_song_remove_part (SfiProxy bse_song_object, SfiProxy part);
void bse_song_remove_track (SfiProxy bse_song_object, SfiProxy track);
void bse_song_synthesize_note (SfiProxy bse_song_object, SfiProxy track, SfiInt duration, SfiInt note, SfiInt fine_tune, SfiReal velocity);
BseErrorType bse_project_restore_from_file (SfiProxy bse_project_object, const gchar* file_name);
BseErrorType bse_project_store_bse (SfiProxy bse_project_object, const gchar* file_name, SfiBool self_contained);
BseErrorType bse_project_activate (SfiProxy bse_project_object);
void bse_project_auto_deactivate (SfiProxy bse_project_object, SfiInt msec_delay);
SfiBool bse_project_can_play (SfiProxy bse_project_object);
SfiProxy bse_project_create_midi_synth (SfiProxy bse_project_object, const gchar* name);
SfiProxy bse_project_create_snet (SfiProxy bse_project_object, const gchar* name);
SfiProxy bse_project_create_song (SfiProxy bse_project_object, const gchar* name);
void bse_project_deactivate (SfiProxy bse_project_object);
SfiProxy bse_project_ensure_wave_repo (SfiProxy bse_project_object);
SfiProxy bse_project_find_item (SfiProxy bse_project_object, const gchar* uname_path);
SfiProxy bse_project_get_data_pocket (SfiProxy bse_project_object, const gchar* name);
BseProjectState bse_project_get_state (SfiProxy bse_project_object);
BseProxySeq* bse_project_get_supers (SfiProxy bse_project_object);
SfiBool bse_project_is_playing (SfiProxy bse_project_object);
BseStringSeq* bse_project_list_uname_paths (SfiProxy bse_project_object, const gchar* item_type);
BseProxySeq* bse_project_match_items_by_uname (SfiProxy bse_project_object, const gchar* item_type, const gchar* uname);
BseErrorType bse_project_play (SfiProxy bse_project_object);
void bse_project_start_playback (SfiProxy bse_project_object);
void bse_project_stop (SfiProxy bse_project_object);
void bse_project_stop_playback (SfiProxy bse_project_object);
SfiBool bse_server_can_load (SfiProxy bse_server_object, const gchar* file_name);
BseNoteDescription* bse_server_construct_note (SfiProxy bse_server_object, SfiInt semitone, SfiInt octave, SfiInt fine_tune);
BseNoteDescription* bse_server_describe_note (SfiProxy bse_server_object, SfiInt note, SfiInt fine_tune);
SfiProxy bse_server_get_midi_notifier (SfiProxy bse_server_object);
SfiInt bse_server_n_scripts (SfiProxy bse_server_object);
BseNoteDescription* bse_server_note_from_freq (SfiProxy bse_server_object, SfiReal freq);
BseNoteDescription* bse_server_note_from_string (SfiProxy bse_server_object, const gchar* name);
SfiBool bse_server_preferences_locked (SfiProxy bse_server_object);
void bse_server_register_plugins (SfiProxy bse_server_object);
void bse_server_register_scripts (SfiProxy bse_server_object);
void bse_server_save_preferences (SfiProxy bse_server_object);
SfiProxy bse_server_use_new_project (SfiProxy bse_server_object, const gchar* name);
void bse_wave_osc_pcm_seek_perc (SfiProxy bse_wave_osc_object, SfiReal pos_perc);
void bse_wave_osc_request_pcm_position (SfiProxy bse_wave_osc_object);
SfiReal bse_wave_chunk_get_mix_freq (SfiProxy bse_wave_object, SfiInt chunk_index);
SfiReal bse_wave_chunk_get_osc_freq (SfiProxy bse_wave_object, SfiInt chunk_index);
BseErrorType bse_wave_load_wave (SfiProxy bse_wave_object, const gchar* file_name, const gchar* wave_name);
SfiInt bse_wave_n_wave_chunks (SfiProxy bse_wave_object);
SfiProxy bse_wave_use_editable (SfiProxy bse_wave_object, SfiInt chunk_index);
SfiInt bse_midi_notifier_current_time (SfiProxy bse_midi_notifier_object);
SfiProxy bse_track_get_part (SfiProxy bse_track_object, SfiInt tick);
BseSongTiming* bse_track_get_timing (SfiProxy bse_track_object, SfiInt tick);
BseErrorType bse_track_insert_part (SfiProxy bse_track_object, SfiInt tick, SfiProxy part);
BseTrackPartSeq* bse_track_list_parts (SfiProxy bse_track_object);
void bse_track_remove_tick (SfiProxy bse_track_object, SfiInt tick);
BseErrorType bse_part_change_note (SfiProxy bse_part_object, SfiInt id, SfiInt tick, SfiInt duration, SfiInt note, SfiInt fine_tune, SfiReal velocity);
BsePartNoteSeq* bse_part_check_overlap (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt note);
BseErrorType bse_part_delete_event (SfiProxy bse_part_object, SfiInt id);
void bse_part_deselect_event (SfiProxy bse_part_object, SfiInt id);
void bse_part_deselect_rectangle (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt min_note, SfiInt max_note);
SfiInt bse_part_get_max_note (SfiProxy bse_part_object);
SfiInt bse_part_get_max_tick (SfiProxy bse_part_object);
SfiInt bse_part_get_min_note (SfiProxy bse_part_object);
BsePartNoteSeq* bse_part_get_notes (SfiProxy bse_part_object, SfiInt tick, SfiInt note);
BseSongTiming* bse_part_get_timing (SfiProxy bse_part_object, SfiInt tick);
SfiInt bse_part_insert_note (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt note, SfiInt fine_tune, SfiReal velocity);
SfiBool bse_part_is_selected_event (SfiProxy bse_part_object, SfiInt id);
BsePartNoteSeq* bse_part_list_notes_crossing (SfiProxy bse_part_object, SfiInt tick, SfiInt duration);
BsePartNoteSeq* bse_part_list_selected_notes (SfiProxy bse_part_object);
void bse_part_queue_notes_within (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt min_note, SfiInt max_note);
void bse_part_select_event (SfiProxy bse_part_object, SfiInt id);
void bse_part_select_rectangle (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt min_note, SfiInt max_note);
void bse_part_select_rectangle_exclusive (SfiProxy bse_part_object, SfiInt tick, SfiInt duration, SfiInt min_note, SfiInt max_note);
SfiInt bse_data_pocket_create_entry (SfiProxy bse_data_pocket_object);
BseErrorType bse_data_pocket_delete_entry (SfiProxy bse_data_pocket_object, SfiInt entry_id);
SfiReal bse_data_pocket_get_float (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
SfiInt bse_data_pocket_get_int (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
SfiInt bse_data_pocket_get_n_entries (SfiProxy bse_data_pocket_object);
SfiInt bse_data_pocket_get_nth_entry_id (SfiProxy bse_data_pocket_object, SfiInt entry_index);
SfiProxy bse_data_pocket_get_object (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
const gchar* bse_data_pocket_get_string (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name);
BseErrorType bse_data_pocket_set_float (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiReal number);
BseErrorType bse_data_pocket_set_int (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiInt number);
BseErrorType bse_data_pocket_set_object (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, SfiProxy item);
BseErrorType bse_data_pocket_set_string (SfiProxy bse_data_pocket_object, SfiInt entry_id, const gchar* name, const gchar* string);
void bse_janitor_add_action (SfiProxy bse_janitor_object, const gchar* action, const gchar* name, const gchar* blurb);
void bse_janitor_exit (SfiProxy bse_janitor_object, BseUserMsgType msg_type, const gchar* message);
const gchar* bse_janitor_get_action (SfiProxy bse_janitor_object, SfiInt nth_action);
const gchar* bse_janitor_get_action_blurb (SfiProxy bse_janitor_object, SfiInt nth_action);
const gchar* bse_janitor_get_action_name (SfiProxy bse_janitor_object, SfiInt nth_action);
const gchar* bse_janitor_get_proc_name (SfiProxy bse_janitor_object);
const gchar* bse_janitor_get_script_name (SfiProxy bse_janitor_object);
void bse_janitor_kill (SfiProxy bse_janitor_object);
SfiInt bse_janitor_n_actions (SfiProxy bse_janitor_object);
void bse_janitor_progress (SfiProxy bse_janitor_object, SfiReal progress);
void bse_janitor_remove_action (SfiProxy bse_janitor_object, const gchar* action);
void bse_janitor_set_msg (SfiProxy bse_janitor_object, BseUserMsgType msg_type, const gchar* message);
void bse_janitor_trigger_action (SfiProxy bse_janitor_object, const gchar* action);
void bse_editable_sample_close (SfiProxy bse_editable_sample_object);
SfiFBlock* bse_editable_sample_collect_stats (SfiProxy bse_editable_sample_object, SfiInt voffset, SfiReal offset_scale, SfiInt block_size, SfiInt stepping, SfiInt max_pairs);
SfiInt bse_editable_sample_get_length (SfiProxy bse_editable_sample_object);
SfiInt bse_editable_sample_get_n_channels (SfiProxy bse_editable_sample_object);
SfiReal bse_editable_sample_get_osc_freq (SfiProxy bse_editable_sample_object);
BseErrorType bse_editable_sample_open (SfiProxy bse_editable_sample_object);
SfiFBlock* bse_editable_sample_read_samples (SfiProxy bse_editable_sample_object, SfiInt voffset);
SfiProxy bse_janitor_get_specific (void);
void bse_hello_world (void);
const gchar* bse_randomizer (SfiBool use_seed, SfiInt seed);
BseCategory* bse_category_from_id (SfiInt category_id);
BseCategorySeq* bse_categories_match (const gchar* pattern);
BseCategorySeq* bse_categories_match_typed (const gchar* pattern, const gchar* type);
const gchar* bse_error_blurb (BseErrorType error);
const gchar* bse_error_name (BseErrorType error);
SfiBool bse_proxy_check (SfiProxy item, const gchar* type_name);
SfiInt bse_note_from_freq (SfiReal frequency);
SfiReal bse_note_to_freq (SfiInt note, SfiInt fine_tune);
const gchar* bse_type_blurb (const gchar* type);


/*-------- end ../sfi/sfidl generated code --------*/


